^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Changelog for package lanelet2_projection
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

1.2.1 (2023-05-10)
------------------

1.2.0 (2023-01-30)
------------------
* add Geocentric and Local Cartesian projectors (`#244 <https://github.com/fzi-forschungszentrum-informatik/Lanelet2/issues/244>`_)
* Correct authorship
* Contributors: Maximilian Naumann, Michał Antkiewicz, Nico Neumann

1.1.1 (2020-09-14)
------------------

1.1.0 (2020-09-06)
------------------
* Add experimental support for building with colcon on ros2 and ament_cmake
* Making all includes in lanelet2_projection consistent.
* Updating package.xml files to format 3.
* Apply clang-tidy 10 recommendations
* Contributors: Fabian Poggenhans, Joshua Whitley

1.0.1 (2020-03-24)
------------------
* Make sure lanelet2 buildtool_export_depends on mrt_cmake_modules
* Add changelogs
* Contributors: Fabian Poggenhans

1.0.0 (2020-03-03)
------------------
* Bump version to 1.0
* Improved readmes and corrected typos
* Initial commit
* Contributors: Fabian Poggenhans
